@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2003, 2006, 2007, 2008 Free Software Foundation, Inc.
+ * Copyright 2003,2006,2007,2008,2009 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -93,7 +93,7 @@ win_fd_isset (int fd, fd_set * set)
 }
 
 #define FD_TO_SOCKET(fd)   ((SOCKET) _get_osfhandle ((fd)))
-#define SOCKET_TO_FD(fh)   (_open_osfhandle ((HANDLE) (fh), O_RDWR | O_BINARY))
+#define SOCKET_TO_FD(fh)   (_open_osfhandle ((long) (fh), O_RDWR | O_BINARY))
 
 #undef close
 #define close		   win_close
@@ -105,6 +105,7 @@ extern int win_close(int filehandle);
 #include <sys/types.h>
 #include <sys/time.h>
 #include <unistd.h>
+#include <fcntl.h>
 #include <errno.h>
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>
@@ -123,6 +124,17 @@ typedef int SOCKET;
 #ifndef SOCKET_ERROR
 #define SOCKET_ERROR		  (-1)
 #endif
+
+#ifndef O_NONBLOCK
+#ifdef O_NDELAY
+#define O_NONBLOCK O_NDELAY
+#else
+#ifdef FNDELAY
+#define O_NONBLOCK FNDELAY
+#endif
+#endif
+#endif
+
 #endif /* !__MSVCRT__ */
 
 #include "getaddrinfo.h"
