@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 2000, 2001, 2002, 2003, 2006, 2008 Free Software Foundation, Inc.
+ * Copyright 2000,2001,2002,2003,2006,2008,2009 Free Software Foundation, Inc.
  * Written by Paolo Bonzini.
  *
  * This file is part of GNU Smalltalk.
@@ -229,7 +229,6 @@ int
 _gst_is_simple_return (bc_vector bytecodes)
 {
   gst_uchar *bytes;
-  size_t byteCodeLen;
   int maybe = MTH_NORMAL;
   OOP maybe_object = NULL;
   int i;
@@ -237,7 +236,6 @@ _gst_is_simple_return (bc_vector bytecodes)
   if (bytecodes == NULL)
     return (MTH_NORMAL);
 
-  byteCodeLen = _gst_bytecode_length (bytecodes);
   bytes = bytecodes->base;
 
   for (i = 1; i <= 3; i++)
@@ -432,7 +430,7 @@ _gst_optimize_bytecodes (bc_vector bytecodes)
 #else
   bc_vector old_bytecodes;
   block_boundary *blocks, *block, *last;
-  gst_uchar *bp, *opt, *end, *first;
+  gst_uchar *bp, *end, *first;
   int i;
   mst_Boolean changed;
 
@@ -606,7 +604,7 @@ _gst_optimize_bytecodes (bc_vector bytecodes)
 
   /* Optimize the single basic blocks.  */
   i = 0;
-  for (bp = opt = bytecodes->base, block = blocks; block != last; block++)
+  for (block = blocks; block != last; block++)
     {
       first = bytecodes->base + block->start;
       bp = bytecodes->base + block->end;
@@ -639,7 +637,7 @@ _gst_optimize_bytecodes (bc_vector bytecodes)
     {
       changed = false;
       i = 0;
-      for (bp = bytecodes->base, block = blocks; block != last; block++)
+      for (block = blocks; block != last; block++)
         {
           int jump_length;
           if (block->final_byte != i)
@@ -763,16 +761,6 @@ optimize_basic_block (gst_uchar *from,
 	 a method).  This almost never happens, so we don't bother.  */
       switch (bp[0])
 	{
-	case LINE_NUMBER_BYTECODE:
-	  /* Remove two consecutive line-number bytecode.  */
-	  if (bp < to - 2
-	      && bp[2] == LINE_NUMBER_BYTECODE)
-	    {
-	      bp += 2;
-	      continue;
-	    }
-	  break;
-
         case PUSH_TEMPORARY_VARIABLE:
         case PUSH_RECEIVER_VARIABLE:
 	  /* Leave only the store in store/pop/push sequences.  Don't do this
@@ -957,8 +945,8 @@ _gst_compute_stack_positions (gst_uchar * bp,
   int bc_len;
 
   bb_start = alloca ((1 + size) * sizeof (basic_block_item *));
-  memzero (bb_start, (1 + size) * sizeof (basic_block_item *));
-  memzero (pos, (1 + size) * sizeof (PTR *));
+  memset (bb_start, 0, (1 + size) * sizeof (basic_block_item *));
+  memset (pos, 0, (1 + size) * sizeof (PTR *));
 
   /* Allocate the first and last basic block specially */
   ALLOCA_BASIC_BLOCK (bb_start, 0, bp, 0);
@@ -1160,7 +1148,7 @@ make_destination_table (gst_uchar * bp,
   gst_uchar *end, *bp_first;
   int count;
 
-  memzero (dest, sizeof (char) * size);
+  memset (dest, 0, sizeof (char) * size);
 
   for (count = 0, end = bp + size; bp != end;
        dest += bp - bp_first)
@@ -1414,7 +1402,7 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
   depth++;
 
   bb_start = alloca ((1 + size) * sizeof (basic_block_item *));
-  memzero (bb_start, (1 + size) * sizeof (basic_block_item *));
+  memset (bb_start, 0, (1 + size) * sizeof (basic_block_item *));
 
   /* Allocate the first and last basic block specially */
   ALLOCA_BASIC_BLOCK(bb_start, stack_depth, bp, num_temps);
@@ -1729,7 +1717,17 @@ _gst_verify_method (OOP methodOOP, int *num_outer_temps, int depth)
 	      *sp++ = _gst_small_integer_class;
 	    }
 
-	    RETURN_METHOD_STACK_TOP,
+	    RETURN_METHOD_STACK_TOP {
+              block_header header;
+	      if (OOP_CLASS (methodOOP) != _gst_compiled_block_class)
+		return "invalid return from method";
+
+              header = GET_BLOCK_HEADER (methodOOP);
+              if (header.clean != (1 << BLK_CLEAN_BITS) - 1)
+		return "invalid return from clean block";
+
+	      break;
+	    }
 	    RETURN_CONTEXT_STACK_TOP { break; }
 
 	    LINE_NUMBER_BYTECODE { }
