@@ -7,7 +7,7 @@
 
 /***********************************************************************
  *
- * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2004,2006,2008
+ * Copyright 1988,89,90,91,92,94,95,99,2000,2001,2002,2004,2006,2008,2009
  * Free Software Foundation, Inc.
  * Written by Steve Byrne.
  *
@@ -104,11 +104,14 @@ static const char help_text[] =
   "\n"
   "\nIn the second form, the file after -f is the last loaded file; any"
   "\nparameter after that file is passed to the Smalltalk program."
-  "\n" "\nReport bugs to help-smalltalk@gnu.org\n";
+  "\n" "\nReport bugs to <help-smalltalk@gnu.org>"
+  "\nGNU Smalltalk home page: <http://smalltalk.gnu.org/>."
+  "\nGeneral help using GNU software: <http://www.gnu.org/gethelp/>."
+  "\n\n";
 
 static const char copyright_and_legal_stuff_text[] =
-  "GNU Smalltalk version %s"
-  "\nCopyright 2006 Free Software Foundation, Inc."
+  "GNU Smalltalk version %s%s"
+  "\nCopyright 2009 Free Software Foundation, Inc."
   "\nWritten by Steve Byrne (sbb@gnu.org) and Paolo Bonzini (bonzini@gnu.org)"
   "\n"
   "\nGNU Smalltalk comes with NO WARRANTY, to the extent permitted by law."
@@ -116,8 +119,9 @@ static const char copyright_and_legal_stuff_text[] =
   "\nGNU General Public License.  For more information, see the file named"
   "\nCOPYING."
   "\n"
-  "\nUsing default kernel path: %s" "\nUsing default image path: %s"
-  "\n";
+  "\nUsing default kernel path: %s"
+  "\nUsing default image path: %s"
+  "\n\n";
 
 #define OPT_KERNEL_DIR 2
 #define OPT_NO_USER 3
@@ -291,6 +295,7 @@ parse_args (int argc,
 
 	case 'v':
 	  printf (copyright_and_legal_stuff_text, VERSION,
+		  PACKAGE_GIT_REVISION,
 		  gst_relocate_path (KERNEL_PATH),
 		  gst_relocate_path (IMAGE_PATH));
 	  exit (0);
