@@ -1,5 +1,5 @@
 /* Test that stack overflow and SIGSEGV are correctly distinguished.
-   Copyright (C) 2002-2005  Bruno Haible <bruno@clisp.org>
+   Copyright (C) 2002-2006  Bruno Haible <bruno@clisp.org>
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -41,6 +41,9 @@
 # include <sys/time.h>
 # include <sys/resource.h>
 #endif
+#ifndef SIGSTKSZ
+# define SIGSTKSZ 16384
+#endif
 
 jmp_buf mainloop;
 sigset_t mainsigset;
@@ -95,13 +98,16 @@ recurse_1 (int n, volatile int *p)
 volatile int
 recurse (volatile int n)
 {
-  return *recurse_1 (n, (volatile int *) &n);
+  return *recurse_1 (n, &n);
 }
 
+/* glibc says: Users should use SIGSTKSZ as the size of user-supplied
+   buffers.  */
+char mystack[SIGSTKSZ];
+
 int
 main ()
 {
-  char mystack[16384];
   sigset_t emptyset;
   void *p;
 
@@ -159,7 +165,7 @@ main ()
       recurse (0);
       printf ("no endless recursion?!\n"); exit (1);
     case 2:
-      *(int *) (page + 0x678) = 42;
+      *(volatile int *) (page + 0x678) = 42;
       break;
     case 3:
       break;
